(function($) {
	$(document).ready(function() {
		$('.Widget_EventCalendar')
		.each(function() {
			// initialize options
			var options = {};
			$('input[type=hidden]', this)
			.each(function() {
				var name = $(this).attr('name');
				var value = $(this).attr('value');
				options[name] = value;
			})
			;
			this.options = options;
			
			// initialize datepicker
			$(this).datepicker({
				dateFormat: 'yy-mm-dd',
				showButtonPanel: true,
				defaultDate: (function(dateText) {
					if(!dateText)
						return new Date();
					var dateParts = dateText.split('-');
					return new Date(Number(dateParts[0]), (Number(dateParts[1]) - 1), Number(dateParts[2]));
				})(this.options.date),
				onSelect: function(dateText) {
					location.href = this.options.calendar + "view/" + dateText;
				},
				beforeShowDay: (!this.options.live) ? null : function(date) {
					if(!this.events)
						return [ !(this.options.async && this.requesting) ];
					
					var year = 1900 + date.getYear();
					var month = date.getMonth() + 1;
					var day = date.getDate();
					var dateText = year.toString() + '-' + ('0' + month.toString()).substring(month.toString().length - 1) + '-' + ('0' + day.toString()).substring(day.toString().length - 1);
					
					if(this.events[dateText])
						return [ true, '', this.events[dateText].join(', ') ];
					
					return [ false ];
				},
				onChangeMonthYear: function(year, month) {
					// generate text version of date
					var dateText = year.toString() + '-' + ('0' + month.toString()).substring(month.toString().length - 1);
					
					// set month and year text for widget
					this.monthYear = dateText;
					
					// live events feature
					if(this.options.live)
					{
						// event controller url
						var controller = this.options.controller + '/' + dateText;
						
						// abort previous requests
						if(this.request) 
							this.request.abort();
						
						// get events for new month
						(function(widget, eventsController) {
							widget.request = $.ajax({
								dataType: 'json',
								url: eventsController,
								async: widget.options.async,
								timeout: widget.options.timeout,
								global: false,
								beforeSend: function() {
									widget.requesting = true;
								},
								success: function(json) {
									widget.events = json;
								},
								complete: function() {
									widget.requesting = false;
									if(widget.options.async) 
										$(widget).datepicker('refresh');
								}
							});
						})(this, controller);
					}
				}
			});
			
			// create month button
			(function(widget) {
				$('.ui-datepicker-title', widget)
				.live('mouseover', function() {
					$(this)
					.not(':has(.ui-datepicker-title-button)')
						.wrapInner('<div class="ui-datepicker-title-button ui-corner-all"></div>')
						.find('.ui-datepicker-title-button')
							.css('font', 'inherit')
							.css('cursor', 'pointer')
						.end()
					.end()
					.find('.ui-datepicker-title-button')
						.addClass('ui-state-default')
						.addClass('ui-state-hover')
						.css('margin', '-1px')
					.end()
					;
				})
				.live('mouseout', function() {
					$(this)
					.find('.ui-datepicker-title-button')
						.removeClass('ui-state-default')
						.removeClass('ui-state-hover')
						.css('margin', '0')
					.end()
					;
				})
				.live('click', function() {
					location.href = widget.options.calendar + "view/" + widget.monthYear;
					return false;
				})
				;
			})(this);
		})
		;
	});
})(jQuery);